==> openshift-model-config-6.8.0-sources.jar: io/fabric8/openshift/api/model/config/v1/OAuthTemplatesFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OAuthTemplatesFluent<A extends OAuthTemplatesFluent<A>> extends BaseFluent<A>{
  public OAuthTemplatesFluent() {
  }
  public OAuthTemplatesFluent(OAuthTemplates instance) {
    instance = (instance != null ? instance : new OAuthTemplates());

    if (instance != null) {
      this.withError(instance.getError());
      this.withLogin(instance.getLogin());
      this.withProviderSelection(instance.getProviderSelection());
      this.withError(instance.getError());
      this.withLogin(instance.getLogin());
      this.withProviderSelection(instance.getProviderSelection());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private SecretNameReferenceBuilder error;
  private SecretNameReferenceBuilder login;
  private SecretNameReferenceBuilder providerSelection;
  private Map<String,Object> additionalProperties;
  public SecretNameReference buildError() {
    return this.error!=null ?this.error.build():null;
  }
  public A withError(SecretNameReference error) {
    _visitables.get("error").remove(this.error);
    if (error!=null){ this.error= new SecretNameReferenceBuilder(error); _visitables.get("error").add(this.error);} else { this.error = null; _visitables.get("error").remove(this.error); } return (A) this;
  }
  public boolean hasError() {
    return this.error != null;
  }
  public A withNewError(String name) {
    return (A)withError(new SecretNameReference(name));
  }
  public ErrorNested<A> withNewError() {
    return new ErrorNested(null);
  }
  public ErrorNested<A> withNewErrorLike(SecretNameReference item) {
    return new ErrorNested(item);
  }
  public ErrorNested<A> editError() {
    return withNewErrorLike(java.util.Optional.ofNullable(buildError()).orElse(null));
  }
  public ErrorNested<A> editOrNewError() {
    return withNewErrorLike(java.util.Optional.ofNullable(buildError()).orElse(new SecretNameReferenceBuilder().build()));
  }
  public ErrorNested<A> editOrNewErrorLike(SecretNameReference item) {
    return withNewErrorLike(java.util.Optional.ofNullable(buildError()).orElse(item));
  }
  public SecretNameReference buildLogin() {
    return this.login!=null ?this.login.build():null;
  }
  public A withLogin(SecretNameReference login) {
    _visitables.get("login").remove(this.login);
    if (login!=null){ this.login= new SecretNameReferenceBuilder(login); _visitables.get("login").add(this.login);} else { this.login = null; _visitables.get("login").remove(this.login); } return (A) this;
  }
  public boolean hasLogin() {
    return this.login != null;
  }
  public A withNewLogin(String name) {
    return (A)withLogin(new SecretNameReference(name));
  }
  public LoginNested<A> withNewLogin() {
    return new LoginNested(null);
  }
  public LoginNested<A> withNewLoginLike(SecretNameReference item) {
    return new LoginNested(item);
  }
  public LoginNested<A> editLogin() {
    return withNewLoginLike(java.util.Optional.ofNullable(buildLogin()).orElse(null));
  }
  public LoginNested<A> editOrNewLogin() {
    return withNewLoginLike(java.util.Optional.ofNullable(buildLogin()).orElse(new SecretNameReferenceBuilder().build()));
  }
  public LoginNested<A> editOrNewLoginLike(SecretNameReference item) {
    return withNewLoginLike(java.util.Optional.ofNullable(buildLogin()).orElse(item));
  }
  public SecretNameReference buildProviderSelection() {
    return this.providerSelection!=null ?this.providerSelection.build():null;
  }
  public A withProviderSelection(SecretNameReference providerSelection) {
    _visitables.get("providerSelection").remove(this.providerSelection);
    if (providerSelection!=null){ this.providerSelection= new SecretNameReferenceBuilder(providerSelection); _visitables.get("providerSelection").add(this.providerSelection);} else { this.providerSelection = null; _visitables.get("providerSelection").remove(this.providerSelection); } return (A) this;
  }
  public boolean hasProviderSelection() {
    return this.providerSelection != null;
  }
  public A withNewProviderSelection(String name) {
    return (A)withProviderSelection(new SecretNameReference(name));
  }
  public ProviderSelectionNested<A> withNewProviderSelection() {
    return new ProviderSelectionNested(null);
  }
  public ProviderSelectionNested<A> withNewProviderSelectionLike(SecretNameReference item) {
    return new ProviderSelectionNested(item);
  }
  public ProviderSelectionNested<A> editProviderSelection() {
    return withNewProviderSelectionLike(java.util.Optional.ofNullable(buildProviderSelection()).orElse(null));
  }
  public ProviderSelectionNested<A> editOrNewProviderSelection() {
    return withNewProviderSelectionLike(java.util.Optional.ofNullable(buildProviderSelection()).orElse(new SecretNameReferenceBuilder().build()));
  }
  public ProviderSelectionNested<A> editOrNewProviderSelectionLike(SecretNameReference item) {
    return withNewProviderSelectionLike(java.util.Optional.ofNullable(buildProviderSelection()).orElse(item));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OAuthTemplatesFluent that = (OAuthTemplatesFluent) o;
    if (!java.util.Objects.equals(error, that.error)) return false;

    if (!java.util.Objects.equals(login, that.login)) return false;

    if (!java.util.Objects.equals(providerSelection, that.providerSelection)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(error,  login,  providerSelection,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (error != null) { sb.append("error:"); sb.append(error + ","); }
    if (login != null) { sb.append("login:"); sb.append(login + ","); }
    if (providerSelection != null) { sb.append("providerSelection:"); sb.append(providerSelection + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ErrorNested<N> extends SecretNameReferenceFluent<ErrorNested<N>> implements Nested<N>{
    ErrorNested(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluent.this.withError(builder.build());
    }
    public N endError() {
      return and();
    }
    
  }
  public class LoginNested<N> extends SecretNameReferenceFluent<LoginNested<N>> implements Nested<N>{
    LoginNested(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluent.this.withLogin(builder.build());
    }
    public N endLogin() {
      return and();
    }
    
  }
  public class ProviderSelectionNested<N> extends SecretNameReferenceFluent<ProviderSelectionNested<N>> implements Nested<N>{
    ProviderSelectionNested(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OAuthTemplatesFluent.this.withProviderSelection(builder.build());
    }
    public N endProviderSelection() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.9.0-sources.jar: io/fabric8/openshift/api/model/config/v1/OAuthTemplatesFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OAuthTemplatesFluent<A extends OAuthTemplatesFluent<A>> extends BaseFluent<A>{
  public OAuthTemplatesFluent() {
  }
  
  public OAuthTemplatesFluent(OAuthTemplates instance) {
    this.copyInstance(instance);
  }
  private SecretNameReferenceBuilder error;
  private SecretNameReferenceBuilder login;
  private SecretNameReferenceBuilder providerSelection;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OAuthTemplates instance) {
    instance = (instance != null ? instance : new OAuthTemplates());
  
    if (instance != null) {
        this.withError(instance.getError());
        this.withLogin(instance.getLogin());
        this.withProviderSelection(instance.getProviderSelection());
        this.withError(instance.getError());
        this.withLogin(instance.getLogin());
        this.withProviderSelection(instance.getProviderSelection());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public SecretNameReference buildError() {
    return this.error!=null ?this.error.build():null;
  }
  
  public A withError(SecretNameReference error) {
    _visitables.get("error").remove(this.error);
    if (error!=null){ this.error= new SecretNameReferenceBuilder(error); _visitables.get("error").add(this.error);} else { this.error = null; _visitables.get("error").remove(this.error); } return (A) this;
  }
  
  public boolean hasError() {
    return this.error != null;
  }
  
  public A withNewError(String name) {
    return (A)withError(new SecretNameReference(name));
  }
  
  public ErrorNested<A> withNewError() {
    return new ErrorNested(null);
  }
  
  public ErrorNested<A> withNewErrorLike(SecretNameReference item) {
    return new ErrorNested(item);
  }
  
  public ErrorNested<A> editError() {
    return withNewErrorLike(java.util.Optional.ofNullable(buildError()).orElse(null));
  }
  
  public ErrorNested<A> editOrNewError() {
    return withNewErrorLike(java.util.Optional.ofNullable(buildError()).orElse(new SecretNameReferenceBuilder().build()));
  }
  
  public ErrorNested<A> editOrNewErrorLike(SecretNameReference item) {
    return withNewErrorLike(java.util.Optional.ofNullable(buildError()).orElse(item));
  }
  
  public SecretNameReference buildLogin() {
    return this.login!=null ?this.login.build():null;
  }
  
  public A withLogin(SecretNameReference login) {
    _visitables.get("login").remove(this.login);
    if (login!=null){ this.login= new SecretNameReferenceBuilder(login); _visitables.get("login").add(this.login);} else { this.login = null; _visitables.get("login").remove(this.login); } return (A) this;
  }
  
  public boolean hasLogin() {
    return this.login != null;
  }
  
  public A withNewLogin(String name) {
    return (A)withLogin(new SecretNameReference(name));
  }
  
  public LoginNested<A> withNewLogin() {
    return new LoginNested(null);
  }
  
  public LoginNested<A> withNewLoginLike(SecretNameReference item) {
    return new LoginNested(item);
  }
  
  public LoginNested<A> editLogin() {
    return withNewLoginLike(java.util.Optional.ofNullable(buildLogin()).orElse(null));
  }
  
  public LoginNested<A> editOrNewLogin() {
    return withNewLoginLike(java.util.Optional.ofNullable(buildLogin()).orElse(new SecretNameReferenceBuilder().build()));
  }
  
  public LoginNested<A> editOrNewLoginLike(SecretNameReference item) {
    return withNewLoginLike(java.util.Optional.ofNullable(buildLogin()).orElse(item));
  }
  
  public SecretNameReference buildProviderSelection() {
    return this.providerSelection!=null ?this.providerSelection.build():null;
  }
  
  public A withProviderSelection(SecretNameReference providerSelection) {
    _visitables.get("providerSelection").remove(this.providerSelection);
    if (providerSelection!=null){ this.providerSelection= new SecretNameReferenceBuilder(providerSelection); _visitables.get("providerSelection").add(this.providerSelection);} else { this.providerSelection = null; _visitables.get("providerSelection").remove(this.providerSelection); } return (A) this;
  }
  
  public boolean hasProviderSelection() {
    return this.providerSelection != null;
  }
  
  public A withNewProviderSelection(String name) {
    return (A)withProviderSelection(new SecretNameReference(name));
  }
  
  public ProviderSelectionNested<A> withNewProviderSelection() {
    return new ProviderSelectionNested(null);
  }
  
  public ProviderSelectionNested<A> withNewProviderSelectionLike(SecretNameReference item) {
    return new ProviderSelectionNested(item);
  }
  
  public ProviderSelectionNested<A> editProviderSelection() {
    return withNewProviderSelectionLike(java.util.Optional.ofNullable(buildProviderSelection()).orElse(null));
  }
  
  public ProviderSelectionNested<A> editOrNewProviderSelection() {
    return withNewProviderSelectionLike(java.util.Optional.ofNullable(buildProviderSelection()).orElse(new SecretNameReferenceBuilder().build()));
  }
  
  public ProviderSelectionNested<A> editOrNewProviderSelectionLike(SecretNameReference item) {
    return withNewProviderSelectionLike(java.util.Optional.ofNullable(buildProviderSelection()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OAuthTemplatesFluent that = (OAuthTemplatesFluent) o;
    if (!java.util.Objects.equals(error, that.error)) return false;
  
    if (!java.util.Objects.equals(login, that.login)) return false;
  
    if (!java.util.Objects.equals(providerSelection, that.providerSelection)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(error,  login,  providerSelection,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (error != null) { sb.append("error:"); sb.append(error + ","); }
    if (login != null) { sb.append("login:"); sb.append(login + ","); }
    if (providerSelection != null) { sb.append("providerSelection:"); sb.append(providerSelection + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ErrorNested<N> extends SecretNameReferenceFluent<ErrorNested<N>> implements Nested<N>{
    ErrorNested(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    SecretNameReferenceBuilder builder;
    
    public N and() {
      return (N) OAuthTemplatesFluent.this.withError(builder.build());
    }
    
    public N endError() {
      return and();
    }
    
  
  }
  public class LoginNested<N> extends SecretNameReferenceFluent<LoginNested<N>> implements Nested<N>{
    LoginNested(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    SecretNameReferenceBuilder builder;
    
    public N and() {
      return (N) OAuthTemplatesFluent.this.withLogin(builder.build());
    }
    
    public N endLogin() {
      return and();
    }
    
  
  }
  public class ProviderSelectionNested<N> extends SecretNameReferenceFluent<ProviderSelectionNested<N>> implements Nested<N>{
    ProviderSelectionNested(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    SecretNameReferenceBuilder builder;
    
    public N and() {
      return (N) OAuthTemplatesFluent.this.withProviderSelection(builder.build());
    }
    
    public N endProviderSelection() {
      return and();
    }
    
  
  }

}
